==> mzanalytics_mybmw-0.5.0.tar.gz: lib/mzanalytics_ios.dart <==
import 'dart:async';
import 'package:flutter/services.dart';
import 'package:mzanalytics_mybmw/mzanalytics_log.dart';

class MzanalyticsiOS {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> appid(String aid) async {
    try {
      //只判断String的类型 系统级异常
      _channel.invokeMethod('appid', {'appid': aid});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<String> getCid() async {
    try {
      final String cid = await _channel.invokeMethod('getCid');
      return cid;
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
    return "";
  }

  static Future<void> setEnableLog(bool parameter) async {
    try {
      _channel.invokeMethod('setEnableLog', {'Enable': parameter});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> enableExceptionService(bool parameter) async {
    try {
      _channel.invokeMethod('enableExceptionService', {'Enable': parameter});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> trackException(Map exception) async {
    try {
      _channel.invokeMethod('trackException', exception);
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> handleOpenURL(String url) async {
    try {
      _channel.invokeMethod('handleOpenURL', {'url': url});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> setCd(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> setCm(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<void> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
  }

  static Future<Map> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
    return Map();
  }

  static Future<bool> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
    return false;
  }

  static Future<List> getManualtrackpage() async {
    try {
      return _channel.invokeMethod('getManualtrackpage');
    } catch (e, stack) {
      MzanalyticsLog.p(e + stack);
    }
    return [];
  }
}

==> mzanalytics_mybmw-0.8.1-dev.3.tar.gz: lib/mzanalytics_ios.dart <==
import 'dart:async';
import 'package:flutter/services.dart';
import 'package:mzanalytics_mybmw/mzanalytics_log.dart';

class MzanalyticsiOS {
  static const MethodChannel _channel =
      const MethodChannel('mzanalytics_mybmw');

  static Future<void> appid(String aid) async {
    try {
      //只判断String的类型 系统级异常
      _channel.invokeMethod('appid', {'appid': aid});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> trackPageView(var parameter) async {
    try {
      _channel.invokeMethod('trackPageView', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> trackEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackEvent', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> trackSiteCustomEvent(var parameter) async {
    try {
      _channel.invokeMethod('trackSiteCustomEvent', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> trackPulse() async {
    try {
      _channel.invokeMethod('trackPulse');
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<String?> getCid() async {
    try {
      return await _channel.invokeMethod('getCid');
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
    return "";
  }

  static Future<void> setEnableLog(bool parameter) async {
    try {
      _channel.invokeMethod('setEnableLog', {'Enable': parameter});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> enableExceptionService(bool parameter) async {
    try {
      _channel.invokeMethod('enableExceptionService', {'Enable': parameter});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  ///setCAIDandVersion
  static Future<void> setCAIDandVersion(Map parameter) async {
    try {
      _channel.invokeMethod('setCAIDandVersion', parameter);
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> trackException(Map exception) async {
    try {
      _channel.invokeMethod('trackException', exception);
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> handleOpenURL(String url) async {
    try {
      _channel.invokeMethod('handleOpenURL', {'url': url});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> setCd(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCd', <String, dynamic>{'cd_key': key, "cd_value": value});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> setCm(var key, var value) async {
    try {
      _channel.invokeMethod(
          'setCm', <String, dynamic>{'cm_key': key, "cm_value": value});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> deleteCd(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCd', <String, dynamic>{'cd_key': key});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<void> deleteCm(var key) async {
    try {
      return _channel
          .invokeMethod('deleteCm', <String, dynamic>{'cm_key': key});
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }

  static Future<Map?> getCdAndCm() async {
    try {
      return _channel.invokeMethod('getCdAndCm');
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
    return Map();
  }

  static Future<bool?> isAutoTrackpage() async {
    try {
      return _channel.invokeMethod('isAutoTrackpage');
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
    return false;
  }

  static Future<List?> getManualtrackpage() async {
    try {
      return _channel.invokeMethod('getManualtrackpage');
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
    return [];
  }

  // ignore: non_constant_identifier_names
  static Future<void> MZNativeErrorTest() async {
    try {
      _channel.invokeMethod('MZNativeErrorTest');
    } catch (e, stack) {
      MzanalyticsLog.p(e.toString() + stack.toString());
    }
  }
}
